@@ -7,6 +7,10 @@ This module provides helpful functions for creating various plots
 import numpy as np
 import matplotlib
 import matplotlib.pyplot as plt
+from pyproj import Transformer
+from bokeh.models import WMTSTileSource, ColumnDataSource
+from bokeh.palettes import Category10, viridis
+from bokeh.plotting import figure
 
 
 plt.close("all")
@@ -710,3 +714,201 @@ def turbine_polar_contour(
         ax_carthesian.set_title("Turbine %s" % (tid))
 
     return ax_carthesian, ax_polar, artists, labels
+
+
+def luminance(rgb):
+
+    """Calculates the brightness of an rgb 255 color. See https://en.wikipedia.org/wiki/Relative_luminance
+
+    Args:
+        rgb(:obj:`tuple`): 255 (red, green, blue) tuple
+
+    Returns:
+        luminance(:obj:`scalar`): relative luminance
+
+    Example:
+
+        .. code-block:: python
+
+            >>> rgb = (255,127,0)
+            >>> luminance(rgb)
+            0.5687976470588235
+
+            >>> luminance((0,50,255))
+            0.21243529411764706
+
+    """
+
+    luminance = (0.2126 * rgb[0] + 0.7152 * rgb[1] + 0.0722 * rgb[2]) / 255
+
+    return luminance
+
+
+def color_to_rgb(color):
+
+    """Converts named colors, hex and normalised RGB to 255 RGB values
+
+    Args:
+        color(:obj:`color`): RGB, HEX or named color
+
+    Returns:
+        rgb(:obj:`tuple`): 255 RGB values
+
+    Example:
+
+        .. code-block:: python
+
+            >>> color_to_rgb("Red")
+            (255, 0, 0)
+
+            >>> color_to_rgb((1,1,0))
+            (255,255,0)
+
+            >>> color_to_rgb("#ff00ff")
+            (255,0,255)
+    """
+
+    if isinstance(color, tuple):
+        if max(color) > 1:
+            color = tuple([i / 255 for i in color])
+
+    rgb = matplotlib.colors.to_rgb(color)
+
+    rgb = tuple([int(i * 255) for i in rgb])
+
+    return rgb
+
+
+def plot_windfarm(
+    project,
+    tile_name="OpenMap",
+    plot_width=800,
+    plot_height=800,
+    marker_size=14,
+    kwargs_for_figure={},
+    kwargs_for_marker={},
+):
+
+    """Plot the windfarm spatially on a map using the Bokeh plotting libaray.
+
+    Args:
+        project(:obj:`plant object`): project to be plotted
+        tile_name(:obj:`str`): tile set to be used for the underlay, e.g. OpenMap, ESRI, OpenTopoMap
+        plot_width(:obj:`scalar`): width of plot
+        plot_height(:obj:`scalar`): height of plot
+        marker_size(:obj:`scalar`): size of markers
+        kwargs_for_figure(:obj:`dict`): additional figure options for advanced users, see Bokeh docs
+        kwargs_for_marker(:obj:`dict`): additional marker options for advanced users, see Bokeh docs. We have some custom behavior around the "fill_color" attribute. If "fill_color" is not defined, OpenOA will use an internally defined color pallete. If "fill_color" is the name of a column in the asset table, OpenOA will use the value of that column as the marker color. Otherwise, "fill_color" is passed through to Bokeh.
+
+    Returns:
+        Bokeh_plot(:obj:`axes handle`): windfarm map
+
+    Example:
+        .. bokeh-plot::
+
+            import pandas as pd
+
+            from bokeh.plotting import figure, output_file, show
+
+            from operational_analysis.toolkits.pandas_plotting import plot_windfarm
+            from operational_analysis.types import PlantData
+
+            from examples.project_ENGIE import Project_Engie
+
+            # Load plant object
+            project = Project_Engie("../examples/data/la_haute_borne")
+
+            # Prepare data
+            project.prepare()
+
+            # Create the bokeh wind farm plot
+            show(plot_windfarm(project,tile_name="ESRI",plot_width=600,plot_height=600))
+    """
+
+    # See https://wiki.openstreetmap.org/wiki/Tile_servers for various tile services
+    MAP_TILES = {
+        "OpenMap": WMTSTileSource(url="http://c.tile.openstreetmap.org/{Z}/{X}/{Y}.png"),
+        "ESRI": WMTSTileSource(
+            url="https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{Z}/{Y}/{X}.jpg"
+        ),
+        "OpenTopoMap": WMTSTileSource(url="https://tile.opentopomap.org/{Z}/{X}/{Y}.png"),
+    }
+
+    # Use pyproj to transform longitude and latitude into web-mercator and add to a copy of the asset dataframe
+    TRANSFORM_4326_TO_3857 = Transformer.from_crs("EPSG:4326", "EPSG:3857")
+
+    assets = project.asset.df.copy()
+    assets["x"], assets["y"] = TRANSFORM_4326_TO_3857.transform(
+        assets["latitude"], assets["longitude"]
+    )
+    assets["coordinates"] = tuple(zip(assets["latitude"], assets["longitude"]))
+
+    # Define default and then update figure and marker options based on kwargs
+    figure_options = {
+        "tools": "save,hover,pan,wheel_zoom,reset,help",
+        "x_axis_label": "Longitude",
+        "y_axis_label": "Latitude",
+        "match_aspect": True,
+        "tooltips": [("id", "@id"), ("type", "@type"), ("(Lat,Lon)", "@coordinates")],
+    }
+    figure_options.update(kwargs_for_figure)
+
+    marker_options = {
+        "marker": "circle_y",
+        "line_width": 1,
+        "alpha": 0.8,
+        "fill_color": "auto_fill_color",
+        "line_color": "auto_line_color",
+        "legend_group": "type",
+    }
+    marker_options.update(kwargs_for_marker)
+
+    # Create an appropriate fill color map and contrasting line color
+    if marker_options["fill_color"] == "auto_fill_color":
+        color_grouping = marker_options["legend_group"]
+
+        assets = assets.sort_values(color_grouping)
+
+        if len(set(assets[color_grouping])) <= 10:
+            color_palette = list(Category10[10])
+        else:
+            color_palette = viridis(len(set(assets[color_grouping])))
+
+        color_mapping = dict(zip(set(assets[color_grouping]), color_palette))
+        assets["auto_fill_color"] = assets[color_grouping].map(color_mapping)
+        assets["auto_fill_color"] = assets["auto_fill_color"].apply(color_to_rgb)
+        assets["auto_line_color"] = [
+            "black" if luminance(color) > 0.5 else "white" for color in assets["auto_fill_color"]
+        ]
+
+    else:
+        if marker_options["fill_color"] in assets.columns:
+            assets[marker_options["fill_color"]] = assets[marker_options["fill_color"]].apply(
+                color_to_rgb
+            )
+            assets["auto_line_color"] = [
+                "black" if luminance(color) > 0.5 else "white"
+                for color in assets[marker_options["fill_color"]]
+            ]
+
+        else:
+            assets["auto_line_color"] = "black"
+
+    # Create the bokeh data source
+    source = ColumnDataSource(assets)
+
+    # Create a bokeh figure with tiles
+    plot_map = figure(
+        plot_width=plot_width,
+        plot_height=plot_height,
+        x_axis_type="mercator",
+        y_axis_type="mercator",
+        **figure_options,
+    )
+
+    plot_map.add_tile(MAP_TILES[tile_name])
+
+    # Plot the asset devices
+    plot_map.scatter(x="x", y="y", source=source, size=marker_size, **marker_options)
+
+    return plot_map
